==> flutter_base_loader-0.0.3.tar.gz: lib/pages/loadpage.dart <==
import 'package:flutter/material.dart';
// import 'package:flutter_base/plugins/base_info.dart';
// import 'package:flutter_base/plugins/base_info.dart';
import 'package:flutter_base_loader/plugins/loading.dart';

class BaseLoadingPage extends StatefulWidget {
  const BaseLoadingPage({
    Key? key,
    this.loading = const Scaffold(
      body: Center(
        child: CircularProgressIndicator(),
      ),
    ),
    this.home = const Scaffold(),
  }) : super(key: key);

  final Widget loading;
  final Widget home;

  // final Future<void>? future;

  @override
  _BaseLoadingPageState createState() => _BaseLoadingPageState();
}

class _BaseLoadingPageState extends State<BaseLoadingPage>
    with WidgetsBindingObserver {
  // late Future<void> _futureBuilderFuture;

  @override
  void initState() {
    baseLoading.instance.pageReady();
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.paused) {
      print("pause");
    }
    if (state == AppLifecycleState.resumed) {
      print("resumed");
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: baseLoading.instance.future,
      builder: (BuildContext context, AsyncSnapshot snapshot) {
        switch (snapshot.connectionState) {
          case ConnectionState.done:
            if (snapshot.hasError) {
              // print("err: ${snapshot.error.toString()}");
              // throw (snapshot.error);
              return Scaffold(
                body: Center(
                  child: Text('error'),
                ),
              );
            }
            return widget.home;
          default:
            print("snapshot.connectionState:${snapshot.connectionState}");
            return widget.loading;
        }
      },
    );
  }
}

==> flutter_base_loader-0.0.4.tar.gz: lib/pages/loadpage.dart <==
import 'package:flutter/material.dart';
// import 'package:flutter_base/plugins/base_info.dart';
// import 'package:flutter_base/plugins/base_info.dart';
import 'package:flutter_base_loader/plugins/loading.dart';

class BaseLoadingPage extends StatefulWidget {
  const BaseLoadingPage({
    Key? key,
    this.loading = const Scaffold(
      body: Center(
        child: CircularProgressIndicator(),
      ),
    ),
    this.home = const Scaffold(),
  }) : super(key: key);

  final Widget loading;
  final Widget home;

  // final Future<void>? future;

  @override
  _BaseLoadingPageState createState() => _BaseLoadingPageState();
}

class _BaseLoadingPageState extends State<BaseLoadingPage>
    with WidgetsBindingObserver {
  // late Future<void> _futureBuilderFuture;

  @override
  void initState() {
    BaseLoading.instance.pageReady();
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.paused) {
      print("pause");
    }
    if (state == AppLifecycleState.resumed) {
      print("resumed");
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: BaseLoading.instance.future,
      builder: (BuildContext context, AsyncSnapshot snapshot) {
        switch (snapshot.connectionState) {
          case ConnectionState.done:
            if (snapshot.hasError) {
              // print("err: ${snapshot.error.toString()}");
              // throw (snapshot.error);
              return Scaffold(
                body: Center(
                  child: Text('error'),
                ),
              );
            }
            return widget.home;
          default:
            print("snapshot.connectionState:${snapshot.connectionState}");
            return widget.loading;
        }
      },
    );
  }
}
